==> release.12.0.73.1.tgz: cgi-cpn/lib_upload.pm <==
#!/usr/bin/perl

# --------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# --------------------------------------------------------------

package lib_upload;

use strict;
use utf8;
use Data::Dumper;

sub agrega_foto_artic {
    my ($foto, $nom_orig, $artic_obj, $foto_original) = @_;

    $artic_obj->get_xml_content();
    # print STDERR "agrega_foto_artic: foto[$foto] nom_orig[$nom_orig]\n";
    # en este punto, aun no se escribe el XML, por si hay errores.
    my $nomfoto = $artic_obj->_add_foto_filesystem($foto, $nom_orig, $foto_original);
    # print STDERR "orig: $nom_orig, nomfoto: $nomfoto\n";
    if (! $nomfoto) {
        print STDERR "Error al guardar imagen [$nom_orig]\n";
        &glib_html_03::print_json_result(0, "Error al guardar imagen");
    }

    # Se deduce del TS del articulo.
    my $fechac = substr($artic_obj->{ts}, 0, 8);

    my $relbase_path = $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'} . $prontus_varglb::DIR_ARTIC . "/$fechac";
    my $relpath_foto = $relbase_path . $prontus_varglb::DIR_IMAG . "/" . $nomfoto;

    if (!-f "$prontus_varglb::DIR_SERVER$relpath_foto") {
        # foto temporal cargada al servidor
        unlink "$prontus_varglb::DIR_SERVER$foto";

        &glib_html_03::print_json_result(0, "La foto generada [$prontus_varglb::DIR_SERVER$relpath_foto] por objeto Artic no existe.");
    }

    my $fotonum;
    if ($nomfoto =~ /^(foto_\d{8})/i) {
        $fotonum = $1;
    } else {
        print STDERR "Error al determinar foto_<numero> de la foto [$nomfoto]\n";
        # foto temporal cargada al servidor
        unlink "$prontus_varglb::DIR_SERVER$foto";
        # foto creada por _add_foto_filesystem.
        unlink "$prontus_varglb::DIR_SERVER$relpath_foto";

        &glib_html_03::print_json_result(0, "Error al determinar foto_<numero> de la foto [$nomfoto]");
    }

    my ($wfoto, $hfoto);
    if ($fotonum) {
        if ($artic_obj->{xml_data} =~ /<(_w$fotonum)>(.+?)<\/\1>/i) {
            $wfoto = $2;
        }
        if ($artic_obj->{xml_data} =~ /<(_h$fotonum)>(.+?)<\/\1>/i) {
            $hfoto = $2;
        }
    }

    if (!$wfoto || !$hfoto) {
        # foto temporal cargada al servidor
        unlink "$prontus_varglb::DIR_SERVER$foto";
        # foto creada por _add_foto_filesystem.
        unlink "$prontus_varglb::DIR_SERVER$relpath_foto";

        &glib_html_03::print_json_result(0, "No se pudo obtener del XML el ancho y el alto de la foto.");
    }

    return ($fotonum, $relpath_foto, $wfoto, $hfoto);
}
# ---------------------------------------------------------------
sub clean_zip_folder {
    my $ts = $_[0];
    # Garbage de archivos antiguos
    my $galeriaproc = "$prontus_varglb::DIR_SERVER/$prontus_varglb::PRONTUS_ID/cpan/procs/galeria";
    my @entrys = glob("$galeriaproc/*");
    my $diff;
    my $modtime;

    foreach my $item (@entrys) {
        $modtime = (stat($item))[9];
        $diff = time - $modtime;
        # print STDERR "galeriaproc[$galeriaproc] item[$item] [$diff]\n";

        if ($diff >= 300) { # le damos 5 minutos de vida.
            # no borramos el directorio sobre el que vamos a trabajar
            if ($ts) {
                next if ($item =~ /$ts$/);
            }
            if (-d $item) {
                system("rm -rf $item &");
            } else {
                unlink $item;
            }
        }
    }
}

1;

==> release.12.2.28.1.tgz: cgi-cpn/lib_upload.pm <==
#!/usr/bin/perl

# --------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# --------------------------------------------------------------
# requiere
# use glib_html_03;
# use prontus_varglb;

package lib_upload;

use strict;
use utf8;

sub agrega_foto_artic {
    my ($foto, $nom_orig, $artic_obj, $foto_original) = @_;

    $artic_obj->get_xml_content();
    # print STDERR "agrega_foto_artic: foto[$foto] nom_orig[$nom_orig]\n";
    # en este punto, aun no se escribe el XML, por si hay errores.
    my $nomfoto = $artic_obj->_add_foto_filesystem($foto, $nom_orig, $foto_original);
    # print STDERR "orig: $nom_orig, nomfoto: $nomfoto\n";
    if (! $nomfoto) {
        print STDERR "Error al guardar imagen [$nom_orig]\n";
        glib_html_03::print_json_result(0, "Error al guardar imagen");
    }

    # Se deduce del TS del articulo.
    my $fechac = substr($artic_obj->{ts}, 0, 8);

    my $relbase_path = $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'} . $prontus_varglb::DIR_ARTIC . "/$fechac";
    my $relpath_foto = $relbase_path . $prontus_varglb::DIR_IMAG . "/" . $nomfoto;

    if (!-f "$prontus_varglb::DIR_SERVER$relpath_foto") {
        # foto temporal cargada al servidor
        unlink "$prontus_varglb::DIR_SERVER$foto";

        glib_html_03::print_json_result(0, "La foto generada [$prontus_varglb::DIR_SERVER$relpath_foto] por objeto Artic no existe.");
    }

    my $fotonum;
    if ($nomfoto =~ /^(foto_\d{8})/i) {
        $fotonum = $1;
    } else {
        print STDERR "Error al determinar foto_<numero> de la foto [$nomfoto]\n";
        # foto temporal cargada al servidor
        unlink "$prontus_varglb::DIR_SERVER$foto";
        # foto creada por _add_foto_filesystem.
        unlink "$prontus_varglb::DIR_SERVER$relpath_foto";

        glib_html_03::print_json_result(0, "Error al determinar foto_<numero> de la foto [$nomfoto]");
    }

    my ($wfoto, $hfoto);
    if ($fotonum) {
        if ($artic_obj->{xml_data} =~ /<(_w$fotonum)>(.+?)<\/\1>/i) {
            $wfoto = $2;
        }
        if ($artic_obj->{xml_data} =~ /<(_h$fotonum)>(.+?)<\/\1>/i) {
            $hfoto = $2;
        }
    }

    if (!$wfoto || !$hfoto) {
        # foto temporal cargada al servidor
        unlink "$prontus_varglb::DIR_SERVER$foto";
        # foto creada por _add_foto_filesystem.
        unlink "$prontus_varglb::DIR_SERVER$relpath_foto";

        glib_html_03::print_json_result(0, "No se pudo obtener del XML el ancho y el alto de la foto.");
    }

    return ($fotonum, $relpath_foto, $wfoto, $hfoto);
}
# ---------------------------------------------------------------
sub clean_zip_folder {
    my $ts = $_[0];
    # Garbage de archivos antiguos
    my $galeriaproc = "$prontus_varglb::DIR_SERVER/$prontus_varglb::PRONTUS_ID/cpan/procs/galeria";
    my @entrys = glob("$galeriaproc/*");
    my $diff;
    my $modtime;

    foreach my $item (@entrys) {
        $modtime = (stat($item))[9];
        $diff = time - $modtime;
        # print STDERR "galeriaproc[$galeriaproc] item[$item] [$diff]\n";

        if ($diff >= 300) { # le damos 5 minutos de vida.
            # no borramos el directorio sobre el que vamos a trabajar
            if ($ts) {
                next if ($item =~ /$ts$/);
            }
            if (-d $item) {
                system("rm -rf $item &");
            } else {
                unlink $item;
            }
        }
    }
}

return 1;
